@@ -35,24 +35,16 @@ ssh
     :nosignatures:
 
     SSH
+    Euler
 
 """
-
-
-class Process(object):
-    pass
-
-
-class Client(object):
-    pass
-
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
 
 from .matlab_ import *
 from .ssh import *
 from .rhino import *
 
-from .matlab_ import __all__ as a
-from .ssh import __all__ as b
-from .rhino import __all__ as c
 
-__all__ = a + b + c
+__all__ = [name for name in dir() if not name.startswith('_')]
