@@ -12,6 +12,7 @@ from ast import literal_eval
 from compas.files import OBJ
 from compas.files import PLY
 from compas.files import STL
+from compas.files import OFF
 
 from compas.utilities import pairwise
 from compas.utilities import window
@@ -19,7 +20,7 @@ from compas.utilities import geometric_key
 
 from compas.geometry import normalize_vector
 from compas.geometry import centroid_points
-from compas.geometry import center_of_mass_polygon
+from compas.geometry import centroid_polygon
 from compas.geometry import cross_vectors
 from compas.geometry import length_vector
 from compas.geometry import subtract_vectors
@@ -27,6 +28,7 @@ from compas.geometry import normal_polygon
 from compas.geometry import area_polygon
 from compas.geometry import bestfit_plane
 from compas.geometry import flatness
+
 from compas.geometry import Polyhedron
 
 from compas.datastructures import Datastructure
@@ -63,6 +65,9 @@ from compas.datastructures.mesh.operations import mesh_split_edge
 from compas.datastructures.mesh.operations import mesh_unweld_vertices
 
 
+__all__ = ['Mesh']
+
+
 TPL = """
 ================================================================================
 Mesh summary
@@ -97,24 +102,6 @@ class Mesh(FromToPickle,
            Datastructure):
     """Definition of a mesh.
 
-    Attributes
-    ----------
-    vertex : dict
-        A dictionary mapping vertex identifiers to vertex attributes.
-    face : dict
-        A dictionary mapping face identifiers to ordered face vertices.
-    halfedge : dict
-        A dictionary mapping each vertex identifier to a dictionary that maps
-        vertex identifiers of the half-edges connected to the first vertex to the
-        corresponding faces.
-    facedata : dict
-        A dictionary mapping face identifiers to face attributes.
-    edgedata : dict
-        A dictionary mapping edge identifiers (pairs of vertex identifiers) to edge
-        attributes.
-    attributes : dict
-        A dictionary of general mesh attributes.
-
     Examples
     --------
     .. plot::
@@ -133,6 +120,8 @@ class Mesh(FromToPickle,
 
     """
 
+    __module__ = 'compas.datastructures'
+
     collapse_edge   = mesh_collapse_edge
     split_face      = mesh_split_face
     split_edge      = mesh_split_edge
@@ -148,12 +137,8 @@ class Mesh(FromToPickle,
         self._key_to_str = False
         self._max_int_key = -1
         self._max_int_fkey = -1
-
         self.attributes = {
-            'name'         : 'Mesh',
-            'color.vertex' : None,
-            'color.edge'   : None,
-            'color.face'   : None,
+            'name' : 'Mesh',
         }
         self.vertex = {}
         self.halfedge = {}
@@ -515,6 +500,36 @@ class Mesh(FromToPickle,
         mesh = cls.from_vertices_and_faces(vertices, faces)
         return mesh
 
+    @classmethod
+    def from_off(cls, filepath):
+        """Construct a mesh object from the data described in a STL file.
+
+        Parameters
+        ----------
+        filepath : str
+            The path to the file.
+
+        Returns
+        -------
+        Mesh :
+            A mesh object.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            import compas
+            from compas.datastructures import Mesh
+
+            mesh = Mesh.from_stl(compas.get('cube_ascii.stl'))
+
+        """
+        off = OFF(filepath)
+        vertices = off.reader.vertices
+        faces = off.reader.faces
+        mesh = cls.from_vertices_and_faces(vertices, faces)
+        return mesh
+
     def leaves(self):
         leaves = []
         for key in self.halfedge:
@@ -1385,6 +1400,69 @@ class Mesh(FromToPickle,
             return False
         return not any(4 != len(self.face_vertices(fkey)) for fkey in self.faces())
 
+    def is_empty(self):
+        """Boolean whether the mesh is empty.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        bool
+            True if no vertices. False otherwise.
+        """
+
+        if self.number_of_vertices() == 0:
+            return True
+
+        return False
+
+    def euler(self):
+        """Calculate the Euler characterisic.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        int
+            The Euler chracteristic.
+        """
+
+        V = len([vkey for vkey in self.vertices() if len(self.vertex_neighbors(vkey)) != 0])
+        E = self.number_of_edges()
+        F = self.number_of_faces()
+        
+        return V - E + F
+
+    def genus(self):
+        """Calculate the genus.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        int
+            The genus.
+
+         References
+        ----------
+        .. [1] Wolfram MathWorld. *Genus*.
+               Available at: http://mathworld.wolfram.com/Genus.html.
+
+        """
+
+        X = self.euler()
+
+        # each boundary must be taken into account as if it was one face
+        B = len(self.boundaries())
+        
+        if mesh.is_orientable:
+            return (2 - (X + B)) / 2
+        else:
+            return 2 - (X + B)
+
     # --------------------------------------------------------------------------
     # accessors
     # --------------------------------------------------------------------------
@@ -1917,6 +1995,43 @@ class Mesh(FromToPickle,
         """
         return self.halfedge[u][v] is None or self.halfedge[v][u] is None
 
+    # --------------------------------------------------------------------------
+    # polyedge topology
+    # --------------------------------------------------------------------------
+
+    def boundaries(self):
+        """Collect the mesh boundaries as lists of vertices.
+
+        Parameters
+        ----------
+        mesh : Mesh
+            Mesh.
+
+        Returns
+        -------
+        boundaries : list
+            List of boundaries as lists of vertex keys.
+
+        """
+
+        boundaries = []
+
+        # get all boundary edges pointing outwards
+        boundary_edges = {u: v for u, v in self.edges_on_boundary()}
+
+        # start new boundary
+        while len(boundary_edges) > 0:
+            boundary = list(boundary_edges.popitem())
+
+            # get consecuvite vertex until the boundary is closed
+            while boundary[0] != boundary[-1]:
+                boundary.append(boundary_edges[boundary[-1]])
+                boundary_edges.pop(boundary[-2])
+
+            boundaries.append(boundary[: -1])
+        
+        return boundaries
+
     # --------------------------------------------------------------------------
     # face topology
     # --------------------------------------------------------------------------
@@ -2147,6 +2262,72 @@ class Mesh(FromToPickle,
             if self.halfedge[v][u] == f2:
                 return u, v
 
+    def is_face_on_boundary(self, key):
+        """Verify that a face is on a boundary.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the face.
+
+        Returns
+        -------
+        bool
+            True if the face is on the boundary.
+            False otherwise.
+
+        """
+        a = [self.halfedge[v][u] for u, v in self.face_halfedges(key)]
+        if None in a:
+            return True
+        else:
+            return False
+    # --------------------------------------------------------------------------
+    # mesh geometry
+    # --------------------------------------------------------------------------
+
+    def area(self):
+        """Calculate the total mesh area.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        float
+            The area.
+        """
+
+        return sum([self.face_area(fkey) for fkey in self.faces()])
+
+    def centroid(self):
+        """Calculate the mesh centroid.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        list
+            The coordinates of the mesh centroid.
+        """
+
+        return scale_vector(1. / self.area(), add_vectors([scale_vector(self.face_area(fkey), self.face_centroid(fkey)) for fkey in mesh.faces()]))
+
+    def normal(self):
+        """Calculate the average mesh normal.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        list
+            The coordinates of the mesh normal.
+        """
+
+        return scale_vector(1. / self.area(), add_vectors([scale_vector(self.face_area(fkey), self.face_normal(fkey)) for fkey in mesh.faces()]))
+
     # --------------------------------------------------------------------------
     # vertex geometry
     # --------------------------------------------------------------------------
@@ -2278,7 +2459,7 @@ class Mesh(FromToPickle,
             The components of the normal vector.
 
         """
-        vectors = [self.face_normal(fkey) for fkey in self.vertex_faces(key) if fkey is not None]
+        vectors = [self.face_normal(fkey, False) for fkey in self.vertex_faces(key) if fkey is not None]
         return normalize_vector(centroid_points(vectors))
 
     # --------------------------------------------------------------------------
@@ -2360,7 +2541,7 @@ class Mesh(FromToPickle,
             The coordinates of the center of mass.
 
         """
-        return center_of_mass_polygon(self.face_coordinates(fkey))
+        return centroid_polygon(self.face_coordinates(fkey))
 
     def face_area(self, fkey):
         """Compute the area of a face.
@@ -2529,16 +2710,30 @@ class Mesh(FromToPickle,
                     faces[self.halfedge[nbr][key]] = 1
         return faces.keys()
 
-    def edges_on_boundary(self):
+    def edges_on_boundary(self, oriented = True):
         """Find the edges on the boundary.
 
+        Parameters
+        ----------
+        oriented : bool
+            Boolean whether the boundary edges should point outwards.
+
         Returns
         -------
-        list
-            The edges on the boundary.
+        boundary_edges : list
+            The boundary edges.
+
 
         """
-        return [(u, v) for u, v in self.edges() if self.is_edge_on_boundary(u, v)]
+
+        boundary_edges =  [(u, v) for u, v in self.edges() if self.is_edge_on_boundary(u, v)]
+        
+        if not oriented:
+            return boundary_edges
+
+        else:
+            return [(v, u) if self.halfedge[u][v] is not None else (u, v) for u, v in boundary_edges]
+
 
     # --------------------------------------------------------------------------
     # attributes
@@ -2869,16 +3064,21 @@ if __name__ == '__main__':
 
     # # mesh.add_face([a, b, c, d, e, f, g, h])
 
-    # plotter = MeshPlotter(mesh)
+    for k in mesh.face:
+        print(k, mesh.is_face_on_boundary(k))
 
-    # plotter.draw_vertices()
-    # plotter.draw_edges()
-    # plotter.draw_faces()
 
-    # plotter.show()
+    plotter = MeshPlotter(mesh)
+
+    plotter.draw_vertices()
+    plotter.draw_edges()
+    plotter.draw_faces(text='key')
+    plotter.show()
+
+    # print(mesh.get_vertices_attribute('x'))
+    # print(mesh.get_vertices_attributes('xy'))
+
+    # print(mesh.get_edges_attribute('q', 1.0))
+    # print(mesh.get_edges_attributes('qf', (1.0, 2.0)))
 
-    print(mesh.get_vertices_attribute('x'))
-    print(mesh.get_vertices_attributes('xy'))
 
-    print(mesh.get_edges_attribute('q', 1.0))
-    print(mesh.get_edges_attributes('qf', (1.0, 2.0)))
