@@ -2,12 +2,12 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-from compas.geometry.basic import cross_vectors
-from compas.geometry.basic import subtract_vectors
-from compas.geometry.basic import dot_vectors
-from compas.geometry.basic import cross_vectors_xy
+from compas.geometry import cross_vectors
+from compas.geometry import subtract_vectors
+from compas.geometry import dot_vectors
+from compas.geometry import cross_vectors_xy
 
-from compas.geometry.distance import distance_point_point
+from compas.geometry import distance_point_point
 
 
 __all__ = [
