@@ -2,17 +2,17 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-from compas.geometry.basic import scale_vector
-from compas.geometry.basic import normalize_vector
-from compas.geometry.basic import add_vectors
-from compas.geometry.basic import subtract_vectors
-from compas.geometry.basic import cross_vectors
+from compas.geometry import scale_vector
+from compas.geometry import normalize_vector
+from compas.geometry import add_vectors
+from compas.geometry import subtract_vectors
+from compas.geometry import cross_vectors
 
-from compas.geometry.average import centroid_points
+from compas.geometry import centroid_points
 
-from compas.geometry.intersections import intersection_line_line
+from compas.geometry import intersection_line_line
 
-from compas.geometry.normals import normal_polygon
+from compas.geometry import normal_polygon
 
 
 __all__ = [
@@ -190,4 +190,34 @@ def offset_polyline(polyline, distance, normal=[0., 0., 1.]):
 
 if __name__ == "__main__":
 
-    pass
+    import compas
+
+    from compas.plotters import Plotter
+    from compas.utilities import pairwise
+    from compas.plotters import MeshPlotter
+
+    from compas.datastructures import Mesh
+
+    mesh = Mesh.from_obj(compas.get('faces.obj'))
+
+    fkey = mesh.get_any_face()
+
+    polyline = mesh.face_coordinates(fkey)
+    polyline.append(polyline[0])
+
+    o = offset_polyline(polyline, 0.1)
+
+    lines = []
+    for a, b in pairwise(o):
+        lines.append({
+            'start' : a,
+            'end'   : b,
+            'color' : '#00ff00',
+            'width' : 0.5
+        })
+
+
+    plotter = MeshPlotter(mesh)
+    plotter.draw_lines(lines)
+    plotter.draw_faces()
+    plotter.show()
