@@ -341,7 +341,12 @@ def decompose_matrix(M):
     >>> allclose(trans1, trans2)
     True
 
+    References
+    ----------
+    .. [1] Slabaugh, 1999. *Computing Euler angles from a rotation matrix*.
+           Available at: http://www.gregslabaugh.net/publications/euler.pdf
     """
+    
     detM = determinant(M)  # raises ValueError if matrix is not squared
 
     if detM == 0:
@@ -395,14 +400,29 @@ def decompose_matrix(M):
         scale = [-x for x in scale]
         row = [[-x for x in y] for y in row]
 
-    # use base vectors??
-    angles[1] = math.asin(-row[0][2])
-    if math.cos(angles[1]):
-        angles[0] = math.atan2(row[1][2], row[2][2])
-        angles[2] = math.atan2(row[0][1], row[0][0])
+    # angles   
+    if row[0][2] != -1. and row[0][2] != 1.:
+
+        beta1 = math.asin(-row[0][2])
+        beta2 = math.pi - beta1
+        
+        alpha1 = math.atan2(row[1][2]/math.cos(beta1), row[2][2]/math.cos(beta1))
+        alpha2 = math.atan2(row[1][2]/math.cos(beta2), row[2][2]/math.cos(beta2))
+
+        gamma1 = math.atan2(row[0][1]/math.cos(beta1), row[0][0]/math.cos(beta1))
+        gamma2 = math.atan2(row[0][1]/math.cos(beta2), row[0][0]/math.cos(beta2))
+
+        angles = [alpha1, beta1, gamma1]
+        # TODO: check for alpha2, beta2, gamma2 needed?
     else:
-        angles[0] = math.atan2(-row[2][1], row[1][1])
-        angles[2] = 0.0
+        gamma = 0.
+        if row[0][2] == -1.:
+            beta = math.pi/2.
+            alpha = gamma + math.atan2(row[1][0], row[2][0])
+        else: # row[0][2] == 1
+            beta = -math.pi/2.
+            alpha = -gamma + math.atan2(-row[1][0], -row[2][0])
+        angles = [alpha, beta, gamma]
 
     # perspective
     if math.fabs(Mt[0][3]) > _EPS and math.fabs(Mt[1][3]) > _EPS and \
@@ -502,7 +522,8 @@ def mesh_transform(mesh, transformation):
     :func:`mesh_transformed`
 
     """
-    xyz = transform_points(mesh.xyz, transformation.matrix)
+    vertices = [mesh.vertex_coordinates(key) for key in mesh.vertices()]
+    xyz = transform_points(vertices, transformation.matrix)
     for i in range(len(xyz)):
         mesh.vertex[i].update({'x': xyz[i][0], 'y': xyz[i][1], 'z': xyz[i][2]})
 
