@@ -19,10 +19,12 @@ Classes
 
 """
 
-from .core import *
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
 
 from .plotter import Plotter
 from .networkplotter import NetworkPlotter
 from .meshplotter import MeshPlotter
 
-__all__ = ['Plotter', 'NetworkPlotter', 'MeshPlotter']
+__all__ = [name for name in dir() if not name.startswith('_')]
