@@ -5,6 +5,37 @@ compas.topology
 
 .. currentmodule:: compas.topology
 
+conway_operators
+-------------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    conway_dual
+    conway_join
+    conway_ambo
+    conway_kis
+    conway_needle
+    conway_zip
+    conway_truncate
+    conway_ortho
+    conway_expand
+    conway_gyro
+    conway_snub
+    conway_meta
+    conway_bevel
+
+connectivity
+-------------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    adjacency_from_edges
+    connectivity_from_edges
+    join_lines_to_polylines
 
 combinatorics
 -------------
@@ -18,6 +49,15 @@ combinatorics
     mesh_is_connected
     network_is_connected
 
+complementarity
+-------------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    network_complement
+
 duality
 -------
 
@@ -102,9 +142,11 @@ triangulation
 
 
 """
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
 
 from .traversal import *
-
 from .combinatorics import *
 from .duality import *
 from .orientation import *
@@ -112,15 +154,7 @@ from .planarity import *
 from .subdivision import *
 from .triangulation import *
 from .connectivity import *
+from .conway import *
+from .complementarity import *
 
-from .combinatorics import __all__ as a
-from .duality import __all__ as b
-from .orientation import __all__ as c
-from .planarity import __all__ as d
-from .subdivision import __all__ as e
-from .traversal import __all__ as f
-from .triangulation import __all__ as g
-from .connectivity import __all__ as h
-
-
-__all__ = a + b + c + d + e + f + g + h
+__all__ = [name for name in dir() if not name.startswith('_')]
