@@ -7,9 +7,22 @@ compas_ghpython
 
 This package contains utilities and helpers for working with COMPAS in Grasshopper.
 
-drawing
+Modules
 =======
 
+.. toctree::
+    :maxdepth: 1
+
+    compas_ghpython.artists
+    compas_ghpython.utilities
+
+
+Functions
+=========
+
+drawing
+-------
+
 .. autosummary::
     :toctree: generated/
 
@@ -27,7 +40,7 @@ drawing
 
 
 sets
-====
+----
 
 .. autosummary::
     :toctree: generated/
@@ -37,7 +50,7 @@ sets
 
 
 timers
-======
+------
 
 .. autosummary::
     :toctree: generated/
@@ -46,14 +59,16 @@ timers
 
 
 utilities
-=========
+---------
 
 .. autosummary::
     :toctree: generated/
 
     unload_modules
 
-
 """
 from .utilities import *
 from .helpers import *
+
+
+__version__ = '0.3.5'
