@@ -19,12 +19,14 @@ Artists for visualising (painting) COMPAS data structures in Rhino.
 """
 from __future__ import absolute_import
 
+from .artist import *
 from .meshartist import *
 from .networkartist import *
 from .volmeshartist import *
 
+from . import artist
 from . import meshartist
 from . import networkartist
 from . import volmeshartist
 
-__all__ = meshartist.__all__ + networkartist.__all__ + volmeshartist.__all__
+__all__ = artist.__all__ + meshartist.__all__ + networkartist.__all__ + volmeshartist.__all__
