@@ -4,7 +4,7 @@ from functools import wraps
 
 import compas
 
-from compas.geometry import center_of_mass_polygon
+from compas.geometry import centroid_polygon
 
 from compas_rhino.utilities import create_layers_from_path
 from compas_rhino.utilities import clear_layer
@@ -530,9 +530,10 @@ def xdraw_mesh(vertices, faces, name=None, color=None, **kwargs):
 def xdraw_faces(faces, **kwargs):
     guids = []
     for face in iter(faces):
-        points = face['points']
+        points = face['points'][:]
         name   = face.get('name')
         color  = face.get('color')
+        vertexcolors = face.get('vertexcolors')
 
         v = len(points)
 
@@ -544,8 +545,21 @@ def xdraw_faces(faces, **kwargs):
             mfaces = [[0, 1, 2, 3]]
         else:
             mfaces = _face_to_max_quad(points, range(v))
+            if vertexcolors:
+                r, g, b = [sum(component) / v for component in zip(*vertexcolors)]
+                r = int(min(max(0, r), 255))
+                g = int(min(max(0, g), 255))
+                b = int(min(max(0, b), 255))
+                vertexcolors.append((r, g, b))
 
         guid = xdraw_mesh(points, mfaces, color=color, name=name, clear=False, redraw=False, layer=None)
+
+        if vertexcolors:
+            try:
+                compas_rhino.set_mesh_vertex_colors(guid, vertexcolors)
+            except Exception:
+                pass
+
         guids.append(guid)
 
     return guids
@@ -554,7 +568,7 @@ def xdraw_faces(faces, **kwargs):
 def _face_to_max_quad(points, face):
     faces = []
     c = len(points)
-    points.append(center_of_mass_polygon(points))
+    points.append(centroid_polygon(points))
     for i in range(-1, len(face) - 1):
         a = face[i]
         b = face[i + 1]
